@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,8 +26,7 @@
 #include <kpluginfactory.h>
 #include <QDir>
 
-K_PLUGIN_FACTORY_WITH_JSON(NylasMailImporterFactory, "nylasmailimporter.json", registerPlugin<NylasMailImportData>();
-                           )
+K_PLUGIN_CLASS_WITH_JSON(NylasMailImportData, "nylasmailimporter.json")
 
 NylasMailImportData::NylasMailImportData(QObject *parent, const QList<QVariant> &)
     : LibImportWizard::AbstractImporter(parent)
