@@ -27,7 +27,6 @@ QTEST_MAIN(MarkdownPluginTest)
 MarkdownPluginTest::MarkdownPluginTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 void MarkdownPluginTest::shouldCreateInterface()
@@ -35,4 +34,6 @@ void MarkdownPluginTest::shouldCreateInterface()
     MarkdownPlugin w;
     KActionCollection *ac = new KActionCollection(this);
     QVERIFY(w.createInterface(ac, this));
+    QVERIFY(w.hasConfigureDialog());
+    QVERIFY(w.hasStatusBarSupport());
 }
