@@ -17,7 +17,6 @@
    Boston, MA 02110-1301, USA.
 */
 
-
 #include "markdownplugin.h"
 #include "markdowninterface.h"
 #include "markdownconfiguredialog.h"
@@ -31,12 +30,10 @@ K_PLUGIN_CLASS_WITH_JSON(MarkdownPlugin, "kmail_markdownplugin.json")
 MarkdownPlugin::MarkdownPlugin(QObject *parent, const QList<QVariant> &)
     : MessageComposer::PluginEditorConvertText(parent)
 {
-
 }
 
 MarkdownPlugin::~MarkdownPlugin()
 {
-
 }
 
 MessageComposer::PluginEditorConvertTextInterface *MarkdownPlugin::createInterface(KActionCollection *ac, QObject *parent)
@@ -47,14 +44,14 @@ MessageComposer::PluginEditorConvertTextInterface *MarkdownPlugin::createInterfa
     return interface;
 }
 
-
 bool MarkdownPlugin::hasConfigureDialog() const
 {
-    return false;
+    return true;
 }
 
 void MarkdownPlugin::showConfigureDialog(QWidget *parent)
 {
+    Q_UNUSED(parent);
     QPointer<MarkdownConfigureDialog> dlg = new MarkdownConfigureDialog(parent);
     if (dlg->exec()) {
         Q_EMIT configChanged();
@@ -67,4 +64,16 @@ QString MarkdownPlugin::description() const
     return i18n("Generate HTML from markdown language.");
 }
 
+bool MarkdownPlugin::canWorkOnHtml() const
+{
+    return false;
+}
+
+bool MarkdownPlugin::hasStatusBarSupport() const
+{
+    return true;
+}
+
 #include "markdownplugin.moc"
+
+
