@@ -34,6 +34,8 @@ public:
     bool hasConfigureDialog() const override;
     void showConfigureDialog(QWidget *parent) override;
     QString description() const override;
+    bool canWorkOnHtml() const override;
+    bool hasStatusBarSupport() const override;
 
 Q_SIGNALS:
     void configChanged();
