@@ -20,6 +20,7 @@
 #include "zoomtextplugineditor.h"
 #include "zoomtextplugineditorinterface.h"
 #include <kpluginfactory.h>
+#include <QLabel>
 
 K_PLUGIN_CLASS_WITH_JSON(ZoomTextPluginEditor, "kmail_zoomtexteditorplugin.json")
 
@@ -44,4 +45,9 @@ bool ZoomTextPluginEditor::hasPopupMenuSupport() const
     return false;
 }
 
+bool ZoomTextPluginEditor::hasStatusBarSupport() const
+{
+    return true;
+}
+
 #include "zoomtextplugineditor.moc"
