@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@ class BriefHeaderStyleInterface : public MessageViewer::HeaderStyleInterface
     Q_OBJECT
 public:
     explicit BriefHeaderStyleInterface(MessageViewer::HeaderStylePlugin *plugin, QObject *parent = nullptr);
-    ~BriefHeaderStyleInterface();
+    ~BriefHeaderStyleInterface() override;
 
     void createAction(KActionMenu *menu, QActionGroup *actionGroup, KActionCollection *ac) override;
     void activateAction() override;
