@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2016-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,7 +31,7 @@ class ADBLOCKLIB_EXPORT AdblockPluginUrlInterceptorConfigureDialog : public PimC
     Q_OBJECT
 public:
     explicit AdblockPluginUrlInterceptorConfigureDialog(QWidget *parent = nullptr);
-    ~AdblockPluginUrlInterceptorConfigureDialog();
+    ~AdblockPluginUrlInterceptorConfigureDialog() override;
 
 protected:
     QWidget *createLayout() override;
